@@ -41,9 +41,12 @@ class Github(Provider):
     def get_raw_file(self, path: str, tag: str):
         return f"{self.source_url}/raw/{tag}/{path}"
 
-    def get_source_file_declaration(self, path: str, tag: str):
+    def get_source_file_declaration(self, path: str, tag: str, branch: str):
         owner_repo = "/".join(self.source_url.split("/")[-2:])
-        return f'github("{owner_repo}", path="{path}", tag="{tag}")'
+        if not (tag or branch):
+            raise UserError("Either tag or branch has to be specified for deployment.")
+        ref_arg = f'tag="{tag}"' if tag is not None else f"branch={branch}"
+        return f'github("{owner_repo}", path="{path}", {ref_arg})'
 
 
 PROVIDERS = [Github]
